function f = C2_fit(FitParms)
%
%  This function calculates a spline function that is linear
%  to the left of FitParms(5) and to the right of FitParms(6)
%  and is a quintic hermite polynomial between the two points.
%
%  Input:  The program needs the cycle numbers (Cycles) from 
%  the LightCycler, and the fit parameters (FitParms).  The
%  Cycles are passed as global variables, and the FitParms are
%  in the call statement and defined as
%
%    slope1 = FitParms(1);  intercept1 = FitParms(2);
%    slope2 = FitParms(3);  intercept2 = FitParms(4);
%    node1  = FitParms(5);  node2      = FitParms(6);
%
%  Output:  The function returns the approximation evaluated
%  at the points defined in Cycles.
%
  global Cycles
%
% quintic hermite polynomial coefficients in descending order
% paste them in with code similar to this to see what they do
%   FitParms = 0:0.01:1;  plot(FitParms,polyval(p0,FitParms))
%
  p0 = [-6  15 -10 0 0 1];
  p1 = [-3   8  -6 0 1 0];
  p2 = [-1   3  -3 1 0 0]/2;

  p3 = [ 6 -15  10 0 0 0];
  p4 = [-3   7  -4 0 0 0];
  p5 = [ 1  -2   1 0 0 0]/2;

%
% extract the fit parameters as:
%
  A1 = FitParms(1);  B1 = FitParms(2);
  A2 = FitParms(3);  B2 = FitParms(4);
  x1 = FitParms(5);  x2 = FitParms(6);

%
% Masks for the domain
%
  Left = zeros(size(Cycles));  Left = ( Cycles <= x1 );
  Right = zeros(size(Cycles)); Right = ( Cycles >= x2 );
  Middle = ones(size(Cycles)) - Left - Right;

%
% Rescale the middle part
%
  Tau = Middle.*(Cycles-x1)/(x2-x1);

%
% Interpolated values
%
  Ileft = (A1*x1) + B1;
  Iright = (A2*x2) + B2;

%
% Approximation
%
  f = (Ileft*polyval(p0,Tau)) + (A1*polyval(p1,Tau)) ...
   + (Iright*polyval(p3,Tau)) + (A2*polyval(p4,Tau));

  f = (Left.*((A1*Cycles)+B1)) + (Middle.*f) + (Right.*((A2*Cycles)+B2));
