function x_max = D2_max(FitParms)
%
%  This function finds the maximum 2nd derivative of a quintic 
%  hermite polynomial.  It does this by calculating the roots of the
%  third derivative (a quadratic).  Then it finds which root corresponds
%  to a max and which to a min by checking the sign of the fourth derivative.
%
%  Input:  FitParms are defined as
%
%    slope1 = FitParms(1);  intercept1 = FitParms(2);
%    slope2 = FitParms(3);  intercept2 = FitParms(4);
%    node1  = FitParms(5);  node2      = FitParms(6);
%
%
%  Output:  The location in cycle numbers of the 2nd derivative maximum
%  of the spline approximation.
%

%
% quintic hermite polynomial coefficients in descending order
% paste them in with code similar to this to see what they do
%   FitParms = 0:0.01:1;  plot(FitParms,polyval(p0,FitParms))
%
% the derivatives were computed with
%  pNp = p0(1:5).*(5:-1:1);
%  pNpp = p0p(1:4).*(4:-1:1);
%  pNppp = p0pp(1:3).*(3:-1:1);
%
% these aren't being used because linear functions are used left and right
%  p2 = [-1   3  -3 1 0 0]/2;
%  p5 = [ 1  -2   1 0 0 0]/2;

  p0 = [-6  15 -10 0 0 1];
  p0ppp = [-360   360   -60];

  p1 = [-3   8  -6 0 1 0];
  p1ppp = [-180   192   -36];

  p3 = [ 6 -15  10 0 0 0];
  p3ppp = [360  -360   60];

  p4 = [-3   7  -4 0 0 0];
  p4ppp = [-180   168   -24];

%
% extract the fit parameters as:
%    A1 = slope1       A2 = slope2       x1 = knot1
%    B1 = intercept1   B2 = intercept2   x2 = knot2
%
  A1 = FitParms(1);  B1 = FitParms(2);
  A2 = FitParms(3);  B2 = FitParms(4);
  x1 = FitParms(5);  x2 = FitParms(6);

%
% Interpolated values
%
  Ileft = (A1*x1) + B1;
  Iright = (A2*x2) + B2;

%
% collect the coefficients of the third derivative
%
  coeffs = (Ileft*p0ppp) + (A1*p1ppp) + (Iright*p3ppp) + (A2*p3ppp);

%
% find its roots
%
  r = roots(coeffs);

%
% calculate the of coefficients of the fourth derivative
%
  Lcoeffs = coeffs(1:2).*(2:-1:1);

%
% determine which root is a max and which is a min.
%

  if polyval(Lcoeffs,r(2)) <= 0
    x_max = r(2)*(x2-x1) + x1;;
  else
    x_max = r(1)*(x2-x1) + x1;;
  end

