function g = approx
%
%  This routine computes a "best" approximation to LightCycler
%  amplification data.  %  The approximation is a spline function
%  that is linear to the left of FitParms(5) and to the right of 
%  FitParms(6) and is a quintic hermite polynomial between the two
%  points.  It is C^2.
%
%  Input:  The program needs the cycle numbers (Cycles) from 
%  the LightCycler, flourescence data for each cycle number and 
%  the fit parameters (FitParms).  The variables are all communicated
%  as global variables.  The FitParms are defined as
%
%    slope1 = FitParms(1);  intercept1 = FitParms(2);
%    slope2 = FitParms(3);  intercept2 = FitParms(4);
%    node1  = FitParms(5);  node2      = FitParms(6);
%
%  Output:  The function returns the "best" approximation evaluated
%  at the points defined in Cycles and the FitParms associated with
%  the "best" approximation.
%

global Cycles
global Data
global FitParms

%
% initial guesses
%
Mcycle = (max(Cycles)+min(Cycles))/2;
FitParms = [ 0 min(Data) 0 max(Data) Mcycle/2 3*Mcycle/2 ];

%
% optimize
%
Options(1:3) = [0 1.e-6 1.e-6];  Options(14) = 400*length(FitParms);
FitParms = fmins('spl_fit',FitParms,Options);
FitParms = fmins('spl_fit',FitParms,Options);

%
% optimized approximation
%
g = C2_fit(FitParms);


